PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE experiment_run (
      run_id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER,
      chunk_unit TEXT NOT NULL,
      chunk_size INTEGER NOT NULL,
      completed INTEGER NOT NULL,
      total INTEGER NOT NULL,
      failed INTEGER NOT NULL,
      queuing INTEGER NOT NULL,
      running INTEGER NOT NULL,
      submitted INTEGER NOT NULL,
      suspended INTEGER NOT NULL DEFAULT 0,
      metadata TEXT
      );
INSERT INTO experiment_run VALUES(1,'2023-08-08-08:43:27','2023-08-08-08:48:57',1691477007,1691477337,'month',1,0,51,0,0,0,0,0,'{"CONFIG": {"MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.85"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "RERUN_JOBLIST": "TRACE_[48, 96, 190, 192, 384, 756]"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_%COMMON.PROCESSORS%": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "[48, 96, 190, 192, 384, 756]"}, "SCALABILITY_%COMMON.PROCESSORS%": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "[48, 96, 190, 192, 384, 756]"}, "STREAM_%HW_BENCHMARKS.STREAM_PROCESSORS%": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "[1, 2, 4, 8, 16, 32, 48]"}, "OSU_RUN_%HW_BENCHMARKS.OSU_PROCESSORS%": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "[48, 96, 192]"}, "TRACE_48": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "48"}, "TRACE_96": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "96"}, "TRACE_192": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "192"}, "SCALABILITY_48": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "SCALABILITY_96": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "SCALABILITY_192": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_190": {"MEMBERS_FROM": {"WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "190"}, "SCALABILITY_190": {"MEMBERS_FROM": {"WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "190"}, "TRACE_384": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "384"}, "TRACE_756": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "756"}, "SCALABILITY_384": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "384"}, "SCALABILITY_756": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "756"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "DIMEMAS": {"FILE": "autosubmit/templates/dimemas.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "DIMEMAS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARAVER": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "MODELFACTORS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_%COMMON.PROCESSORS%": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "[48, 96, 190, 192, 384, 756]", "ADDITIONAL_FILES": []}, "TRACE_%COMMON.PROCESSORS%": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "[48, 96, 190, 192, 384, 756]", "ADDITIONAL_FILES": []}, "OSU_RUN_%HW_BENCHMARKS.OSU_PROCESSORS%": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "[48, 96, 192]", "ADDITIONAL_FILES": []}, "STREAM_%HW_BENCHMARKS.STREAM_PROCESSORS%": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "[1, 2, 4, 8, 16, 32, 48]", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "48", "FILE": "", "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "96", "FILE": "", "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "192", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_48": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "48", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_96": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "96", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_192": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "192", "FILE": "", "ADDITIONAL_FILES": []}, "SCALABILITY_190": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "190", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_190": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "190", "FILE": "", "ADDITIONAL_FILES": []}, "SCALABILITY_384": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "384", "FILE": "", "ADDITIONAL_FILES": []}, "SCALABILITY_756": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "756", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_384": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "PROCESSORS": "384", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_756": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "PROCESSORS": "756", "FILE": "", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80", "PROCESSORS": [48, 96, 190, 192, 384, 756]}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "REPORT": {"CONFIG": "%CFG%/latex/report.cfg", "NAME": "report", "PATH": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "OSU_PROCESSORS": [48, 96, 192], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "PROCESSORS": [48, 96, 190]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "PROCESSORS": [384, 756]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "PROCESSORS": [48, 96, 192]}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a014", "PROJDIR": "/home/dbeltran/new_autosubmit/a014/proj/project_files", "DEFAULT": {"EXPID": "a6ab", "HPCARCH": "local", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a014/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a014/proj/auto-performance-profiling/autosubmit/configuration/preset-1/", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(2,'2023-08-08-08:48:58','2023-08-08-08:55:02',1691477338,1691477702,'month',1,0,51,0,0,0,0,0,'{"CONFIG": {"MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.85"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "RERUN_JOBLIST": "TRACE_[48, 96, 190, 192, 384, 756]"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_%COMMON.PROCESSORS%": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "[48, 96, 190, 192, 384, 756]"}, "SCALABILITY_%COMMON.PROCESSORS%": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "[48, 96, 190, 192, 384, 756]"}, "STREAM_%HW_BENCHMARKS.STREAM_PROCESSORS%": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "[1, 2, 4, 8, 16, 32, 48]"}, "OSU_RUN_%HW_BENCHMARKS.OSU_PROCESSORS%": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "[48, 96, 192]"}, "TRACE_48": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "48"}, "TRACE_96": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "96"}, "TRACE_192": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "192"}, "SCALABILITY_48": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "SCALABILITY_96": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "SCALABILITY_192": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_190": {"MEMBERS_FROM": {"WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "190"}, "SCALABILITY_190": {"MEMBERS_FROM": {"WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "190"}, "TRACE_384": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "384"}, "TRACE_756": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "756"}, "SCALABILITY_384": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "384"}, "SCALABILITY_756": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "756"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "DIMEMAS": {"FILE": "autosubmit/templates/dimemas.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "DIMEMAS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARAVER": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "MODELFACTORS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_%COMMON.PROCESSORS%": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "[48, 96, 190, 192, 384, 756]", "ADDITIONAL_FILES": []}, "TRACE_%COMMON.PROCESSORS%": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "[48, 96, 190, 192, 384, 756]", "ADDITIONAL_FILES": []}, "OSU_RUN_%HW_BENCHMARKS.OSU_PROCESSORS%": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "[48, 96, 192]", "ADDITIONAL_FILES": []}, "STREAM_%HW_BENCHMARKS.STREAM_PROCESSORS%": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "[1, 2, 4, 8, 16, 32, 48]", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "48", "FILE": "", "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "96", "FILE": "", "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "192", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_48": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "48", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_96": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "96", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_192": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "192", "FILE": "", "ADDITIONAL_FILES": []}, "SCALABILITY_190": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "190", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_190": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "190", "FILE": "", "ADDITIONAL_FILES": []}, "SCALABILITY_384": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "384", "FILE": "", "ADDITIONAL_FILES": []}, "SCALABILITY_756": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "756", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_384": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "PROCESSORS": "384", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_756": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "PROCESSORS": "756", "FILE": "", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80", "PROCESSORS": "[48, 96, 190, 192, 384, 756]"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "REPORT": {"CONFIG": "%CFG%/latex/report.cfg", "NAME": "report", "PATH": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "OSU_PROCESSORS": [48, 96, 192], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "PROCESSORS": [48, 96, 190]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "PROCESSORS": [384, 756]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "PROCESSORS": [48, 96, 192]}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a014", "PROJDIR": "/home/dbeltran/new_autosubmit/a014/proj/project_files", "DEFAULT": {"EXPID": "a6ab", "HPCARCH": "local", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a014/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a014/proj/auto-performance-profiling/autosubmit/configuration/preset-1/", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(3,'2023-08-08-08:55:02','2023-08-08-08:57:14',1691477702,1691477834,'month',1,0,51,0,0,0,0,0,'{"CONFIG": {"MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.85"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "RERUN_JOBLIST": "TRACE_[48, 96, 190, 192, 384, 756]"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_%COMMON.PROCESSORS%": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "[48, 96, 190, 192, 384, 756]"}, "SCALABILITY_%COMMON.PROCESSORS%": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "[48, 96, 190, 192, 384, 756]"}, "STREAM_%HW_BENCHMARKS.STREAM_PROCESSORS%": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "[1, 2, 4, 8, 16, 32, 48]"}, "OSU_RUN_%HW_BENCHMARKS.OSU_PROCESSORS%": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "[48, 96, 192]"}, "TRACE_48": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "48"}, "TRACE_96": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "96"}, "TRACE_192": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "192"}, "SCALABILITY_48": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "SCALABILITY_96": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "SCALABILITY_192": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_190": {"MEMBERS_FROM": {"WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "190"}, "SCALABILITY_190": {"MEMBERS_FROM": {"WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "190"}, "TRACE_384": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "384"}, "TRACE_756": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "756"}, "SCALABILITY_384": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "384"}, "SCALABILITY_756": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "756"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "DIMEMAS": {"FILE": "autosubmit/templates/dimemas.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "DIMEMAS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARAVER": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "MODELFACTORS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_%COMMON.PROCESSORS%": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "[48, 96, 190, 192, 384, 756]", "ADDITIONAL_FILES": []}, "TRACE_%COMMON.PROCESSORS%": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "[48, 96, 190, 192, 384, 756]", "ADDITIONAL_FILES": []}, "OSU_RUN_%HW_BENCHMARKS.OSU_PROCESSORS%": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "[48, 96, 192]", "ADDITIONAL_FILES": []}, "STREAM_%HW_BENCHMARKS.STREAM_PROCESSORS%": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "[1, 2, 4, 8, 16, 32, 48]", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "48", "FILE": "", "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "96", "FILE": "", "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "192", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_48": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "48", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_96": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "96", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_192": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "192", "FILE": "", "ADDITIONAL_FILES": []}, "SCALABILITY_190": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "190", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_190": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "190", "FILE": "", "ADDITIONAL_FILES": []}, "SCALABILITY_384": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "384", "FILE": "", "ADDITIONAL_FILES": []}, "SCALABILITY_756": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "756", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_384": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "PROCESSORS": "384", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_756": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "PROCESSORS": "756", "FILE": "", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80", "PROCESSORS": [48, 96, 190, 192, 384, 756]}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "REPORT": {"CONFIG": "%CFG%/latex/report.cfg", "NAME": "report", "PATH": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "OSU_PROCESSORS": [48, 96, 192], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "PROCESSORS": [48, 96, 190]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "PROCESSORS": [384, 756]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "PROCESSORS": [48, 96, 192]}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a014", "PROJDIR": "/home/dbeltran/new_autosubmit/a014/proj/project_files", "DEFAULT": {"EXPID": "a6ab", "HPCARCH": "local", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a014/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a014/proj/auto-performance-profiling/autosubmit/configuration/preset-1/", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(4,'2023-08-08-08:57:14','2023-08-08-08:58:50',1691477834,1691477930,'month',1,0,51,0,0,0,0,0,'{"CONFIG": {"MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.85"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "RERUN_JOBLIST": "TRACE_[48, 96, 190, 192, 384, 756]"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_%COMMON.PROCESSORS%": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "[48, 96, 190, 192, 384, 756]"}, "SCALABILITY_%COMMON.PROCESSORS%": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "[48, 96, 190, 192, 384, 756]"}, "STREAM_%HW_BENCHMARKS.STREAM_PROCESSORS%": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "[1, 2, 4, 8, 16, 32, 48]"}, "OSU_RUN_%HW_BENCHMARKS.OSU_PROCESSORS%": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "[48, 96, 192]"}, "TRACE_48": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "48"}, "TRACE_96": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "96"}, "TRACE_192": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "192"}, "SCALABILITY_48": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "SCALABILITY_96": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "SCALABILITY_192": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_190": {"MEMBERS_FROM": {"WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "190"}, "SCALABILITY_190": {"MEMBERS_FROM": {"WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "190"}, "TRACE_384": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "384"}, "TRACE_756": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "756"}, "SCALABILITY_384": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "384"}, "SCALABILITY_756": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "756"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "DIMEMAS": {"FILE": "autosubmit/templates/dimemas.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "DIMEMAS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARAVER": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "MODELFACTORS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_%COMMON.PROCESSORS%": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "[48, 96, 190, 192, 384, 756]", "ADDITIONAL_FILES": []}, "TRACE_%COMMON.PROCESSORS%": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "[48, 96, 190, 192, 384, 756]", "ADDITIONAL_FILES": []}, "OSU_RUN_%HW_BENCHMARKS.OSU_PROCESSORS%": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "[48, 96, 192]", "ADDITIONAL_FILES": []}, "STREAM_%HW_BENCHMARKS.STREAM_PROCESSORS%": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "[1, 2, 4, 8, 16, 32, 48]", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "48", "FILE": "", "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "96", "FILE": "", "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "192", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_48": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "48", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_96": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "96", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_192": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "192", "FILE": "", "ADDITIONAL_FILES": []}, "SCALABILITY_190": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "190", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_190": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "190", "FILE": "", "ADDITIONAL_FILES": []}, "SCALABILITY_384": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "384", "FILE": "", "ADDITIONAL_FILES": []}, "SCALABILITY_756": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "756", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_384": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "PROCESSORS": "384", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_756": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "PROCESSORS": "756", "FILE": "", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80", "PROCESSORS": [48, 96, 190, 192, 384, 756]}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "REPORT": {"CONFIG": "%CFG%/latex/report.cfg", "NAME": "report", "PATH": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "OSU_PROCESSORS": [48, 96, 192], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "PROCESSORS": [48, 96, 190]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "PROCESSORS": [384, 756]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "PROCESSORS": [48, 96, 192]}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a014", "PROJDIR": "/home/dbeltran/new_autosubmit/a014/proj/project_files", "DEFAULT": {"EXPID": "a6ab", "HPCARCH": "local", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a014/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a014/proj/auto-performance-profiling/autosubmit/configuration/preset-1/", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(5,'2023-08-08-08:58:50','2023-08-08-09:11:09',1691477930,1691478669,'month',1,0,51,0,0,0,0,0,'{"CONFIG": {"MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.85"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "RERUN_JOBLIST": "TRACE_[48, 96, 190, 192, 384, 756]"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_%COMMON.PROCESSORS%": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "[48, 96, 190, 192, 384, 756]"}, "SCALABILITY_%COMMON.PROCESSORS%": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "[48, 96, 190, 192, 384, 756]"}, "STREAM_%HW_BENCHMARKS.STREAM_PROCESSORS%": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "[1, 2, 4, 8, 16, 32, 48]"}, "OSU_RUN_%HW_BENCHMARKS.OSU_PROCESSORS%": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "[48, 96, 192]"}, "TRACE_48": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "48"}, "TRACE_96": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "96"}, "TRACE_192": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "192"}, "SCALABILITY_48": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "SCALABILITY_96": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "SCALABILITY_192": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_190": {"MEMBERS_FROM": {"WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "190"}, "SCALABILITY_190": {"MEMBERS_FROM": {"WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "190"}, "TRACE_384": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "384"}, "TRACE_756": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "756"}, "SCALABILITY_384": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "384"}, "SCALABILITY_756": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "756"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "DIMEMAS": {"FILE": "autosubmit/templates/dimemas.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "DIMEMAS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARAVER": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "MODELFACTORS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_%COMMON.PROCESSORS%": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "[48, 96, 190, 192, 384, 756]", "ADDITIONAL_FILES": []}, "TRACE_%COMMON.PROCESSORS%": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "[48, 96, 190, 192, 384, 756]", "ADDITIONAL_FILES": []}, "OSU_RUN_%HW_BENCHMARKS.OSU_PROCESSORS%": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "[48, 96, 192]", "ADDITIONAL_FILES": []}, "STREAM_%HW_BENCHMARKS.STREAM_PROCESSORS%": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "[1, 2, 4, 8, 16, 32, 48]", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "48", "FILE": "", "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "96", "FILE": "", "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "192", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_48": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "48", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_96": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "96", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_192": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "192", "FILE": "", "ADDITIONAL_FILES": []}, "SCALABILITY_190": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "190", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_190": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "190", "FILE": "", "ADDITIONAL_FILES": []}, "SCALABILITY_384": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "384", "FILE": "", "ADDITIONAL_FILES": []}, "SCALABILITY_756": {"DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "PROCESSORS": "756", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_384": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "PROCESSORS": "384", "FILE": "", "ADDITIONAL_FILES": []}, "TRACE_756": {"DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "PROCESSORS": "756", "FILE": "", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80", "PROCESSORS": [48, 96, 190, 192, 384, 756]}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "REPORT": {"CONFIG": "%CFG%/latex/report.cfg", "NAME": "report", "PATH": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "OSU_PROCESSORS": [48, 96, 192], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "PROCESSORS": [48, 96, 190]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "PROCESSORS": [384, 756]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "PROCESSORS": [48, 96, 192]}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a014", "PROJDIR": "/home/dbeltran/new_autosubmit/a014/proj/project_files", "DEFAULT": {"EXPID": "a6ab", "HPCARCH": "local", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a014/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a014/proj/auto-performance-profiling/autosubmit/configuration/preset-1/", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(6,'2023-08-08-09:11:09','2023-08-08-09:17:21',1691478669,1691479041,'month',1,1,67,1,0,0,0,0,'{"COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80", "PROCESSORS": [48, 96, 190, 192, 384, 756]}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "REPORT": {"CONFIG": "%CFG%/latex/report.cfg", "NAME": "report", "PATH": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "OSU_PROCESSORS": [48, 96, 192], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "PROCESSORS": [48, 96, 190]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "PROCESSORS": [384, 756]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "PROCESSORS": [48, 96, 192]}, "CONFIG": {"MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.85"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "RERUN_JOBLIST": "TRACE_[48, 96, 190, 192, 384, 756]"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "48"}, "TRACE_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "96"}, "TRACE_190": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "190"}, "TRACE_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_384": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "384"}, "TRACE_756": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "756"}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "SCALABILITY_190": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "190"}, "SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "SCALABILITY_384": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "384"}, "SCALABILITY_756": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "756"}, "STREAM_1": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "1"}, "STREAM_2": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "2"}, "STREAM_4": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "4"}, "STREAM_8": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "8"}, "STREAM_16": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "16"}, "STREAM_32": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "32"}, "STREAM_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_96": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "OSU_RUN_192": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "DIMEMAS": {"FILE": "autosubmit/templates/dimemas.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "DIMEMAS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARAVER": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "MODELFACTORS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_190": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "190", "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "SCALABILITY_384": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "384", "ADDITIONAL_FILES": []}, "SCALABILITY_756": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "756", "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_190": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "190", "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "TRACE_384": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "384", "ADDITIONAL_FILES": []}, "TRACE_756": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "756", "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "1", "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "2", "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "4", "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "8", "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "16", "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "32", "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a014", "PROJDIR": "/home/dbeltran/new_autosubmit/a014/proj/project_files", "DEFAULT": {"EXPID": "a6ab", "HPCARCH": "local", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a014/proj/auto-performance-profiling/autosubmit/configuration/common/proj.yml,/home/dbeltran/new_autosubmit/a014/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a014/proj/auto-performance-profiling/autosubmit/configuration/preset-1/", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(7,'2023-08-08-09:17:21','2023-08-08-09:20:56',1691479041,1691479256,'month',1,1,67,1,0,0,0,0,'{"COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80", "PROCESSORS": [48, 96, 190, 192, 384, 756]}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "REPORT": {"CONFIG": "%CFG%/latex/report.cfg", "NAME": "report", "PATH": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "OSU_PROCESSORS": [48, 96, 192], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "PROCESSORS": [48, 96, 190]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "PROCESSORS": [384, 756]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "PROCESSORS": [48, 96, 192]}, "CONFIG": {"MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.85"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "RERUN_JOBLIST": "TRACE_[48, 96, 190, 192, 384, 756]"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "48"}, "TRACE_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "96"}, "TRACE_190": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "190"}, "TRACE_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_384": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "384"}, "TRACE_756": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "756"}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "SCALABILITY_190": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "190"}, "SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "SCALABILITY_384": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "384"}, "SCALABILITY_756": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "756"}, "STREAM_1": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "1"}, "STREAM_2": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "2"}, "STREAM_4": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "4"}, "STREAM_8": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "8"}, "STREAM_16": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "16"}, "STREAM_32": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "32"}, "STREAM_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_96": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "OSU_RUN_192": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "DIMEMAS": {"FILE": "autosubmit/templates/dimemas.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "DIMEMAS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARAVER": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "MODELFACTORS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_190": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "190", "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "SCALABILITY_384": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "384", "ADDITIONAL_FILES": []}, "SCALABILITY_756": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "756", "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_190": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "190", "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "TRACE_384": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "384", "ADDITIONAL_FILES": []}, "TRACE_756": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "756", "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "1", "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "2", "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "4", "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "8", "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "16", "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "32", "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a014", "PROJDIR": "/home/dbeltran/new_autosubmit/a014/proj/project_files", "DEFAULT": {"EXPID": "a014", "HPCARCH": "local", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a014/proj/auto-performance-profiling/autosubmit/configuration/common/proj.yml,/home/dbeltran/new_autosubmit/a014/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a014/proj/auto-performance-profiling/autosubmit/configuration/preset-1/", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(8,'2023-08-08-09:20:56','2023-08-08-09:25:32',1691479256,1691479532,'month',1,1,67,1,0,0,0,0,'{"COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80", "PROCESSORS": [48, 96, 190, 192, 384, 756]}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "REPORT": {"CONFIG": "%CFG%/latex/report.cfg", "NAME": "report", "PATH": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "OSU_PROCESSORS": [48, 96, 192], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "PROCESSORS": [48, 96, 190]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "PROCESSORS": [384, 756]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "PROCESSORS": [48, 96, 192]}, "CONFIG": {"MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.85"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "RERUN_JOBLIST": "TRACE_[48, 96, 190, 192, 384, 756]"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "48"}, "TRACE_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "96"}, "TRACE_190": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "190"}, "TRACE_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_384": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "384"}, "TRACE_756": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "756"}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "SCALABILITY_190": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "190"}, "SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "SCALABILITY_384": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "384"}, "SCALABILITY_756": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "756"}, "STREAM_1": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "1"}, "STREAM_2": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "2"}, "STREAM_4": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "4"}, "STREAM_8": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "8"}, "STREAM_16": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "16"}, "STREAM_32": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "32"}, "STREAM_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_96": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "OSU_RUN_192": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "DIMEMAS": {"FILE": "autosubmit/templates/dimemas.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "DIMEMAS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARAVER": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "MODELFACTORS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_190": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "190", "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "SCALABILITY_384": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "384", "ADDITIONAL_FILES": []}, "SCALABILITY_756": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "756", "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_190": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "190", "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "TRACE_384": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "384", "ADDITIONAL_FILES": []}, "TRACE_756": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "756", "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "1", "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "2", "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "4", "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "8", "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "16", "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "32", "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a014", "PROJDIR": "/home/dbeltran/new_autosubmit/a014/proj/project_files", "DEFAULT": {"EXPID": "a014", "HPCARCH": "local", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a014/proj/auto-performance-profiling/autosubmit/configuration/common/proj.yml,/home/dbeltran/new_autosubmit/a014/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a014/proj/auto-performance-profiling/autosubmit/configuration/preset-1/", "POST": "~/platforms_credentials.yml"}}}');
INSERT INTO experiment_run VALUES(9,'2023-08-08-09:25:32','2023-08-08-09:33:08',1691479532,0,'month',1,53,67,0,0,0,3,0,'{"COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80", "PROCESSORS": [48, 96, 190, 192, 384, 756]}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation", "PROVIDED_TRACES_PATH": "", "CFG": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "REPORT": {"CONFIG": "%CFG%/latex/report.cfg", "NAME": "report", "PATH": "%CURRENT_ROOTDIR%/report"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks", "OSU_PROCESSORS": [48, 96, 192], "STREAM_PROCESSORS": [1, 2, 4, 8, 16, 32, 48]}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling", "PROCESSORS": [48, 96, 190]}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling", "PROCESSORS": [384, 756]}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency", "PROCESSORS": [48, 96, 192]}, "CONFIG": {"MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE", "AUTOSUBMIT_VERSION": "4.0.85"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "RERUN_JOBLIST": "TRACE_[48, 96, 190, 192, 384, 756]"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "REPORT_SETUP": {"FILE": "autosubmit/templates/report_setup.sh", "DEPENDENCIES": {"TRACE_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "48"}, "TRACE_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "96"}, "TRACE_190": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "190"}, "TRACE_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "192"}, "TRACE_384": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "384"}, "TRACE_756": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}, "PROCESSORS": "756"}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "SCALABILITY_190": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "190"}, "SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}, "SCALABILITY_384": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "384"}, "SCALABILITY_756": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "756"}, "STREAM_1": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "1"}, "STREAM_2": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "2"}, "STREAM_4": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "4"}, "STREAM_8": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "8"}, "STREAM_16": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "16"}, "STREAM_32": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "32"}, "STREAM_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_48": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "48"}, "OSU_RUN_96": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "96"}, "OSU_RUN_192": {"MEMBERS_FROM": {"STRONGSCALING, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}, "PROCESSORS": "192"}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "TRACE_CUT": {"FILE": "autosubmit/templates/trace_cut.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "DIMEMAS": {"FILE": "autosubmit/templates/dimemas.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAMEDIR": {"FILE": "autosubmit/templates/paramedir.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "PARAVER": {"FILE": "autosubmit/templates/paraver.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "HARDWARE_BENCH_IMAGES": {"FILE": "autosubmit/templates/hardware_bench_images.sh", "DEPENDENCIES": {"REPORT_SETUP": {"MEMBERS_FROM": {"STRONGSCALING, WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "MODELFACTORS": {"FILE": "autosubmit/templates/modelfactors.sh", "DEPENDENCIES": {"TRACE_CUT": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "CONFIGURATION_JSON": {"FILE": "autosubmit/templates/configuration_json.sh", "DEPENDENCIES": {"PARAMEDIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "DIMEMAS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "ADD_SECTION": {"FILE": "autosubmit/templates/add_section.sh", "DEPENDENCIES": {"CONFIGURATION_JSON": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "PARAVER": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "HARDWARE_BENCH_IMAGES": {"MEMBERS_FROM": {"WEAKSCALING, STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "MODELFACTORS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY, WEAKSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REPORT": {"FILE": "autosubmit/templates/report.sh", "DEPENDENCIES": {"ADD_SECTION": {}}, "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "SCALABILITY_190": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "190", "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "SCALABILITY_384": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "384", "ADDITIONAL_FILES": []}, "SCALABILITY_756": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "756", "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "TRACE_190": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "190", "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "TRACE_384": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "384", "ADDITIONAL_FILES": []}, "TRACE_756": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY, HARDWAREBENCHMARKS": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "#SBATCH -C perfparanoid", "PROCESSORS": "756", "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "96", "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "192", "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "1", "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "2", "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "4", "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "8", "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "16", "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "32", "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": "48", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a014", "PROJDIR": "/home/dbeltran/new_autosubmit/a014/proj/auto-performance-profiling", "DEFAULT": {"EXPID": "a014", "HPCARCH": "local", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a014/proj/auto-performance-profiling/autosubmit/configuration/common/proj.yml,/home/dbeltran/new_autosubmit/a014/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a014/proj/auto-performance-profiling/autosubmit/configuration/preset-1/", "POST": "~/platforms_credentials.yml"}}}');
CREATE TABLE job_data (
      id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      counter INTEGER NOT NULL,
      job_name TEXT NOT NULL,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      submit INTEGER NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER NOT NULL,
      status TEXT NOT NULL,
      rowtype INTEGER NOT NULL,
      ncpus INTEGER NOT NULL,
      wallclock TEXT NOT NULL,
      qos TEXT NOT NULL,
      energy INTEGER NOT NULL,
      date TEXT NOT NULL,
      section TEXT NOT NULL,
      member TEXT NOT NULL,
      chunk INTEGER NOT NULL,
      last INTEGER NOT NULL,
      platform TEXT NOT NULL,
      job_id INTEGER NOT NULL,
      extra_data TEXT NOT NULL,
      nnodes INTEGER NOT NULL DEFAULT 0,
      run_id INTEGER,
      MaxRSS REAL NOT NULL DEFAULT 0.0,
      AveRSS REAL NOT NULL DEFAULT 0.0,
      out TEXT NOT NULL,
      err TEXT NOT NULL,
      rowstatus INTEGER NOT NULL DEFAULT 0,
      children TEXT,
      platform_output TEXT,
      UNIQUE(counter,job_name)
      );
INSERT INTO job_data VALUES(1,0,'a014_CLEAN','2023-08-08-09:14:36','2023-08-08-09:17:53',1691478876,1691478876,1691478876,'COMPLETED',2,1,'00:30','debug',0,'','CLEAN','',0,0,'MARENOSTRUM0',91798,'',0,6,0.0,0.0,'a014_CLEAN.20230808091450.out','a014_CLEAN.20230808091450.err',5,'a014_REMOTE_SETUP','');
INSERT INTO job_data VALUES(2,0,'a014_REMOTE_SETUP','2023-08-08-09:14:55','2023-08-08-09:18:12',1691478895,1691478895,1691478913,'FAILED',2,1,'00:30','debug',0,'','REMOTE_SETUP','',0,0,'MARENOSTRUM0',92263,'',0,6,0.0,0.0,'a014_REMOTE_SETUP.20230808091512.out','a014_REMOTE_SETUP.20230808091512.err',5,'a014_20210811_CompilationEfficiency_REMOTE_INIDATA,a014_20210811_WeakScaling_REMOTE_INIDATA,a014_20210811_StrongScaling_REMOTE_INIDATA,a014_20210811_HardwareBenchmarks_REMOTE_INIDATA','');
INSERT INTO job_data VALUES(3,1,'a014_CLEAN','2023-08-08-09:17:53','2023-08-08-09:21:26',1691479073,1691479073,1691479073,'COMPLETED',2,1,'00:30','debug',0,'','CLEAN','',0,0,'MARENOSTRUM0',95011,'',0,7,0.0,0.0,'a014_CLEAN.20230808091807.out','a014_CLEAN.20230808091807.err',5,'a014_REMOTE_SETUP','');
INSERT INTO job_data VALUES(4,1,'a014_REMOTE_SETUP','2023-08-08-09:18:12','2023-08-08-09:21:45',1691479092,1691479092,1691479106,'FAILED',2,1,'00:30','debug',0,'','REMOTE_SETUP','',0,0,'MARENOSTRUM0',95476,'',0,7,0.0,0.0,'a014_REMOTE_SETUP.20230808091826.out','a014_REMOTE_SETUP.20230808091826.err',5,'a014_20210811_CompilationEfficiency_REMOTE_INIDATA,a014_20210811_WeakScaling_REMOTE_INIDATA,a014_20210811_StrongScaling_REMOTE_INIDATA,a014_20210811_HardwareBenchmarks_REMOTE_INIDATA','');
INSERT INTO job_data VALUES(5,2,'a014_CLEAN','2023-08-08-09:21:26','2023-08-08-09:26:01',1691479286,1691479286,1691479286,'COMPLETED',2,1,'00:30','debug',0,'','CLEAN','',0,0,'MARENOSTRUM0',98912,'',0,8,0.0,0.0,'a014_CLEAN.20230808092140.out','a014_CLEAN.20230808092140.err',5,'a014_REMOTE_SETUP','');
INSERT INTO job_data VALUES(6,2,'a014_REMOTE_SETUP','2023-08-08-09:21:45','2023-08-08-09:26:20',1691479305,1691479305,1691479319,'FAILED',2,1,'00:30','debug',0,'','REMOTE_SETUP','',0,0,'MARENOSTRUM0',99377,'',0,8,0.0,0.0,'a014_REMOTE_SETUP.20230808092159.out','a014_REMOTE_SETUP.20230808092159.err',5,'a014_20210811_CompilationEfficiency_REMOTE_INIDATA,a014_20210811_WeakScaling_REMOTE_INIDATA,a014_20210811_StrongScaling_REMOTE_INIDATA,a014_20210811_HardwareBenchmarks_REMOTE_INIDATA','');
INSERT INTO job_data VALUES(7,3,'a014_CLEAN','2023-08-08-09:26:01','2023-08-08-09:26:16',1691479561,1691479561,1691479566,'COMPLETED',2,1,'00:30','debug',0,'','CLEAN','',0,1,'MARENOSTRUM0',101491,'',0,9,0.0,0.0,'a014_CLEAN.20230808092616.out','a014_CLEAN.20230808092616.err',5,'a014_REMOTE_SETUP','');
INSERT INTO job_data VALUES(8,3,'a014_REMOTE_SETUP','2023-08-08-09:26:20','2023-08-08-09:26:35',1691479580,1691479580,1691479585,'COMPLETED',2,1,'00:30','debug',0,'','REMOTE_SETUP','',0,1,'MARENOSTRUM0',101952,'',0,9,0.0,0.0,'a014_REMOTE_SETUP.20230808092634.out','a014_REMOTE_SETUP.20230808092634.err',5,'a014_20210811_CompilationEfficiency_REMOTE_INIDATA,a014_20210811_WeakScaling_REMOTE_INIDATA,a014_20210811_StrongScaling_REMOTE_INIDATA,a014_20210811_HardwareBenchmarks_REMOTE_INIDATA','');
INSERT INTO job_data VALUES(9,3,'a014_20210811_CompilationEfficiency_REMOTE_INIDATA','2023-08-08-09:26:39','2023-08-08-09:27:10',1691479599,1691479599,1691479604,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','CompilationEfficiency',0,1,'MARENOSTRUM0',103128,'',0,9,0.0,0.0,'a014_20210811_CompilationEfficiency_REMOTE_INIDATA.20230808092710.out','a014_20210811_CompilationEfficiency_REMOTE_INIDATA.20230808092710.err',5,'a014_20210811_CompilationEfficiency_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(10,3,'a014_20210811_HardwareBenchmarks_REMOTE_INIDATA','2023-08-08-09:26:43','2023-08-08-09:27:10',1691479603,1691479603,1691479608,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','HardwareBenchmarks',0,1,'MARENOSTRUM0',103586,'',0,9,0.0,0.0,'a014_20210811_HardwareBenchmarks_REMOTE_INIDATA.20230808092710.out','a014_20210811_HardwareBenchmarks_REMOTE_INIDATA.20230808092710.err',5,'a014_20210811_HardwareBenchmarks_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(11,3,'a014_20210811_WeakScaling_REMOTE_INIDATA','2023-08-08-09:26:48','2023-08-08-09:27:11',1691479608,1691479608,1691479613,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','WeakScaling',0,1,'MARENOSTRUM0',104048,'',0,9,0.0,0.0,'a014_20210811_WeakScaling_REMOTE_INIDATA.20230808092711.out','a014_20210811_WeakScaling_REMOTE_INIDATA.20230808092711.err',5,'a014_20210811_WeakScaling_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(12,3,'a014_20210811_CompilationEfficiency_REMOTE_COMPILATION','2023-08-08-09:27:16','2023-08-08-09:27:48',1691479635,1691479635,1691479640,'COMPLETED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','CompilationEfficiency',0,1,'MARENOSTRUM0',104826,'',0,9,0.0,0.0,'a014_20210811_CompilationEfficiency_REMOTE_COMPILATION.20230808092748.out','a014_20210811_CompilationEfficiency_REMOTE_COMPILATION.20230808092748.err',5,'a014_20210811_CompilationEfficiency_PREPARE_TESTS','');
INSERT INTO job_data VALUES(13,3,'a014_20210811_HardwareBenchmarks_REMOTE_COMPILATION','2023-08-08-09:27:21','2023-08-08-09:27:48',1691479641,1691479641,1691479646,'COMPLETED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','HardwareBenchmarks',0,1,'MARENOSTRUM0',105637,'',0,9,0.0,0.0,'a014_20210811_HardwareBenchmarks_REMOTE_COMPILATION.20230808092748.out','a014_20210811_HardwareBenchmarks_REMOTE_COMPILATION.20230808092748.err',5,'a014_20210811_HardwareBenchmarks_PREPARE_TESTS','');
INSERT INTO job_data VALUES(14,3,'a014_20210811_WeakScaling_REMOTE_COMPILATION','2023-08-08-09:27:25','2023-08-08-09:27:49',1691479645,1691479645,1691479650,'COMPLETED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','WeakScaling',0,1,'MARENOSTRUM0',106356,'',0,9,0.0,0.0,'a014_20210811_WeakScaling_REMOTE_COMPILATION.20230808092749.out','a014_20210811_WeakScaling_REMOTE_COMPILATION.20230808092749.err',5,'a014_20210811_WeakScaling_PREPARE_TESTS','');
INSERT INTO job_data VALUES(15,3,'a014_20210811_StrongScaling_REMOTE_INIDATA','2023-08-08-09:27:54','2023-08-08-09:28:10',1691479673,1691479673,1691479678,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REMOTE_INIDATA','StrongScaling',0,1,'MARENOSTRUM0',107123,'',0,9,0.0,0.0,'a014_20210811_StrongScaling_REMOTE_INIDATA.20230808092810.out','a014_20210811_StrongScaling_REMOTE_INIDATA.20230808092810.err',5,'a014_20210811_StrongScaling_REMOTE_COMPILATION','');
INSERT INTO job_data VALUES(16,3,'a014_20210811_CompilationEfficiency_PREPARE_TESTS','2023-08-08-09:27:55','2023-08-08-09:28:16',1691479674,1691479674,1691479679,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','PREPARE_TESTS','CompilationEfficiency',0,1,'LOCAL',20101,'',0,9,0.0,0.0,'a014_20210811_CompilationEfficiency_PREPARE_TESTS.20230808092816.out','a014_20210811_CompilationEfficiency_PREPARE_TESTS.20230808092816.err',5,'a014_20210811_CompilationEfficiency_SCALABILITY_48,a014_20210811_CompilationEfficiency_FUNCTIONS_DIR,a014_20210811_CompilationEfficiency_SCALABILITY_192,a014_20210811_CompilationEfficiency_SCALABILITY_190,a014_20210811_CompilationEfficiency_SCALABILITY_96','');
INSERT INTO job_data VALUES(17,3,'a014_20210811_HardwareBenchmarks_PREPARE_TESTS','2023-08-08-09:27:55','2023-08-08-09:28:16',1691479675,1691479675,1691479680,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','PREPARE_TESTS','HardwareBenchmarks',0,1,'LOCAL',20129,'',0,9,0.0,0.0,'a014_20210811_HardwareBenchmarks_PREPARE_TESTS.20230808092816.out','a014_20210811_HardwareBenchmarks_PREPARE_TESTS.20230808092816.err',5,'a014_20210811_HardwareBenchmarks_STREAM_32,a014_20210811_HardwareBenchmarks_OSU_RUN_48,a014_20210811_HardwareBenchmarks_STREAM_1,a014_20210811_HardwareBenchmarks_STREAM_48,a014_20210811_HardwareBenchmarks_STREAM_16,a014_20210811_HardwareBenchmarks_OSU_RUN_192,a014_20210811_HardwareBenchmarks_STREAM_8,a014_20210811_HardwareBenchmarks_OSU_RUN_96,a014_20210811_HardwareBenchmarks_STREAM_4,a014_20210811_HardwareBenchmarks_STREAM_2','');
INSERT INTO job_data VALUES(18,3,'a014_20210811_WeakScaling_PREPARE_TESTS','2023-08-08-09:27:56','2023-08-08-09:28:16',1691479676,1691479676,1691479681,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','PREPARE_TESTS','WeakScaling',0,1,'LOCAL',20154,'',0,9,0.0,0.0,'a014_20210811_WeakScaling_PREPARE_TESTS.20230808092816.out','a014_20210811_WeakScaling_PREPARE_TESTS.20230808092816.err',5,'a014_20210811_WeakScaling_SCALABILITY_756,a014_20210811_WeakScaling_FUNCTIONS_DIR,a014_20210811_WeakScaling_SCALABILITY_384','');
INSERT INTO job_data VALUES(19,3,'a014_20210811_StrongScaling_REMOTE_COMPILATION','2023-08-08-09:28:21','2023-08-08-09:28:40',1691479701,1691479701,1691479706,'COMPLETED',2,4,'00:50','debug',0,'2021-08-11 00:00:00','REMOTE_COMPILATION','StrongScaling',0,1,'MARENOSTRUM0',110543,'',0,9,0.0,0.0,'a014_20210811_StrongScaling_REMOTE_COMPILATION.20230808092840.out','a014_20210811_StrongScaling_REMOTE_COMPILATION.20230808092840.err',5,'a014_20210811_StrongScaling_PREPARE_TESTS','');
INSERT INTO job_data VALUES(20,3,'a014_20210811_HardwareBenchmarks_STREAM_48','2023-08-08-09:28:22','2023-08-08-09:28:46',1691479702,1691479702,1691479707,'COMPLETED',2,48,'00:30','debug',0,'2021-08-11 00:00:00','STREAM_48','HardwareBenchmarks',0,1,'LOCAL',20292,'',0,9,0.0,0.0,'a014_20210811_HardwareBenchmarks_STREAM_48.20230808092846.out','a014_20210811_HardwareBenchmarks_STREAM_48.20230808092846.err',5,'a014_20210811_HardwareBenchmarks_REPORT_SETUP','');
INSERT INTO job_data VALUES(21,3,'a014_20210811_HardwareBenchmarks_STREAM_32','2023-08-08-09:28:24','2023-08-08-09:28:46',1691479703,1691479703,1691479708,'COMPLETED',2,32,'00:30','debug',0,'2021-08-11 00:00:00','STREAM_32','HardwareBenchmarks',0,1,'LOCAL',20317,'',0,9,0.0,0.0,'a014_20210811_HardwareBenchmarks_STREAM_32.20230808092846.out','a014_20210811_HardwareBenchmarks_STREAM_32.20230808092846.err',5,'a014_20210811_HardwareBenchmarks_REPORT_SETUP','');
INSERT INTO job_data VALUES(22,3,'a014_20210811_HardwareBenchmarks_STREAM_16','2023-08-08-09:28:25','2023-08-08-09:28:46',1691479705,1691479705,1691479710,'COMPLETED',2,16,'00:30','debug',0,'2021-08-11 00:00:00','STREAM_16','HardwareBenchmarks',0,1,'LOCAL',20340,'',0,9,0.0,0.0,'a014_20210811_HardwareBenchmarks_STREAM_16.20230808092846.out','a014_20210811_HardwareBenchmarks_STREAM_16.20230808092846.err',5,'a014_20210811_HardwareBenchmarks_REPORT_SETUP','');
INSERT INTO job_data VALUES(23,3,'a014_20210811_HardwareBenchmarks_STREAM_8','2023-08-08-09:28:46','2023-08-08-09:29:03',1691479726,1691479726,1691479731,'COMPLETED',2,8,'00:30','debug',0,'2021-08-11 00:00:00','STREAM_8','HardwareBenchmarks',0,1,'LOCAL',20474,'',0,9,0.0,0.0,'a014_20210811_HardwareBenchmarks_STREAM_8.20230808092903.out','a014_20210811_HardwareBenchmarks_STREAM_8.20230808092903.err',5,'a014_20210811_HardwareBenchmarks_REPORT_SETUP','');
INSERT INTO job_data VALUES(24,3,'a014_20210811_HardwareBenchmarks_STREAM_4','2023-08-08-09:28:46','2023-08-08-09:29:03',1691479726,1691479726,1691479731,'COMPLETED',2,4,'00:30','debug',0,'2021-08-11 00:00:00','STREAM_4','HardwareBenchmarks',0,1,'LOCAL',20497,'',0,9,0.0,0.0,'a014_20210811_HardwareBenchmarks_STREAM_4.20230808092903.out','a014_20210811_HardwareBenchmarks_STREAM_4.20230808092903.err',5,'a014_20210811_HardwareBenchmarks_REPORT_SETUP','');
INSERT INTO job_data VALUES(25,3,'a014_20210811_HardwareBenchmarks_STREAM_2','2023-08-08-09:28:47','2023-08-08-09:29:03',1691479727,1691479727,1691479732,'COMPLETED',2,2,'00:30','debug',0,'2021-08-11 00:00:00','STREAM_2','HardwareBenchmarks',0,1,'LOCAL',20520,'',0,9,0.0,0.0,'a014_20210811_HardwareBenchmarks_STREAM_2.20230808092903.out','a014_20210811_HardwareBenchmarks_STREAM_2.20230808092903.err',5,'a014_20210811_HardwareBenchmarks_REPORT_SETUP','');
INSERT INTO job_data VALUES(26,3,'a014_20210811_HardwareBenchmarks_STREAM_1','2023-08-08-09:29:03','2023-08-08-09:29:20',1691479743,1691479743,1691479748,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','STREAM_1','HardwareBenchmarks',0,1,'LOCAL',20584,'',0,9,0.0,0.0,'a014_20210811_HardwareBenchmarks_STREAM_1.20230808092920.out','a014_20210811_HardwareBenchmarks_STREAM_1.20230808092920.err',5,'a014_20210811_HardwareBenchmarks_REPORT_SETUP','');
INSERT INTO job_data VALUES(27,3,'a014_20210811_HardwareBenchmarks_OSU_RUN_192','2023-08-08-09:29:03','2023-08-08-09:29:20',1691479743,1691479743,1691479748,'COMPLETED',2,192,'00:30','debug',0,'2021-08-11 00:00:00','OSU_RUN_192','HardwareBenchmarks',0,1,'LOCAL',20607,'',0,9,0.0,0.0,'a014_20210811_HardwareBenchmarks_OSU_RUN_192.20230808092920.out','a014_20210811_HardwareBenchmarks_OSU_RUN_192.20230808092920.err',5,'a014_20210811_HardwareBenchmarks_REPORT_SETUP','');
INSERT INTO job_data VALUES(28,3,'a014_20210811_HardwareBenchmarks_OSU_RUN_96','2023-08-08-09:29:04','2023-08-08-09:29:20',1691479744,1691479744,1691479749,'COMPLETED',2,96,'00:30','debug',0,'2021-08-11 00:00:00','OSU_RUN_96','HardwareBenchmarks',0,1,'LOCAL',20630,'',0,9,0.0,0.0,'a014_20210811_HardwareBenchmarks_OSU_RUN_96.20230808092920.out','a014_20210811_HardwareBenchmarks_OSU_RUN_96.20230808092920.err',5,'a014_20210811_HardwareBenchmarks_REPORT_SETUP','');
INSERT INTO job_data VALUES(29,3,'a014_20210811_HardwareBenchmarks_OSU_RUN_48','2023-08-08-09:29:20','2023-08-08-09:29:37',1691479760,1691479760,1691479765,'COMPLETED',2,48,'00:30','debug',0,'2021-08-11 00:00:00','OSU_RUN_48','HardwareBenchmarks',0,1,'LOCAL',20699,'',0,9,0.0,0.0,'a014_20210811_HardwareBenchmarks_OSU_RUN_48.20230808092937.out','a014_20210811_HardwareBenchmarks_OSU_RUN_48.20230808092937.err',5,'a014_20210811_HardwareBenchmarks_REPORT_SETUP','');
INSERT INTO job_data VALUES(30,3,'a014_20210811_WeakScaling_SCALABILITY_756','2023-08-08-09:29:20','2023-08-08-09:29:37',1691479760,1691479760,1691479765,'COMPLETED',2,756,'02:00','debug',0,'2021-08-11 00:00:00','SCALABILITY_756','WeakScaling',0,1,'LOCAL',20722,'',0,9,0.0,0.0,'a014_20210811_WeakScaling_SCALABILITY_756.20230808092937.out','a014_20210811_WeakScaling_SCALABILITY_756.20230808092937.err',5,'a014_20210811_WeakScaling_REPORT_SETUP','');
INSERT INTO job_data VALUES(31,3,'a014_20210811_WeakScaling_SCALABILITY_384','2023-08-08-09:29:21','2023-08-08-09:29:37',1691479761,1691479761,1691479766,'COMPLETED',2,384,'02:00','debug',0,'2021-08-11 00:00:00','SCALABILITY_384','WeakScaling',0,1,'LOCAL',20745,'',0,9,0.0,0.0,'a014_20210811_WeakScaling_SCALABILITY_384.20230808092937.out','a014_20210811_WeakScaling_SCALABILITY_384.20230808092937.err',5,'a014_20210811_WeakScaling_REPORT_SETUP','');
INSERT INTO job_data VALUES(32,3,'a014_20210811_HardwareBenchmarks_REPORT_SETUP','2023-08-08-09:29:41','2023-08-08-09:29:59',1691479781,1691479781,1691479786,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REPORT_SETUP','HardwareBenchmarks',0,1,'MARENOSTRUM0',111370,'',0,9,0.0,0.0,'a014_20210811_HardwareBenchmarks_REPORT_SETUP.20230808092959.out','a014_20210811_HardwareBenchmarks_REPORT_SETUP.20230808092959.err',5,'a014_20210811_HardwareBenchmarks_HARDWARE_BENCH_IMAGES','');
INSERT INTO job_data VALUES(33,3,'a014_20210811_CompilationEfficiency_SCALABILITY_192','2023-08-08-09:29:41','2023-08-08-09:30:05',1691479781,1691479781,1691479786,'COMPLETED',2,192,'02:00','debug',0,'2021-08-11 00:00:00','SCALABILITY_192','CompilationEfficiency',0,1,'LOCAL',20823,'',0,9,0.0,0.0,'a014_20210811_CompilationEfficiency_SCALABILITY_192.20230808093005.out','a014_20210811_CompilationEfficiency_SCALABILITY_192.20230808093005.err',5,'a014_20210811_CompilationEfficiency_REPORT_SETUP','');
INSERT INTO job_data VALUES(34,3,'a014_20210811_CompilationEfficiency_SCALABILITY_190','2023-08-08-09:29:42','2023-08-08-09:30:05',1691479782,1691479782,1691479787,'COMPLETED',2,190,'02:00','debug',0,'2021-08-11 00:00:00','SCALABILITY_190','CompilationEfficiency',0,1,'LOCAL',20846,'',0,9,0.0,0.0,'a014_20210811_CompilationEfficiency_SCALABILITY_190.20230808093005.out','a014_20210811_CompilationEfficiency_SCALABILITY_190.20230808093005.err',5,'a014_20210811_CompilationEfficiency_REPORT_SETUP','');
INSERT INTO job_data VALUES(35,3,'a014_20210811_CompilationEfficiency_SCALABILITY_96','2023-08-08-09:29:44','2023-08-08-09:30:05',1691479783,1691479783,1691479788,'COMPLETED',2,96,'02:00','debug',0,'2021-08-11 00:00:00','SCALABILITY_96','CompilationEfficiency',0,1,'LOCAL',20869,'',0,9,0.0,0.0,'a014_20210811_CompilationEfficiency_SCALABILITY_96.20230808093005.out','a014_20210811_CompilationEfficiency_SCALABILITY_96.20230808093005.err',5,'a014_20210811_CompilationEfficiency_REPORT_SETUP','');
INSERT INTO job_data VALUES(36,3,'a014_20210811_HardwareBenchmarks_HARDWARE_BENCH_IMAGES','2023-08-08-09:30:17','2023-08-08-09:30:32',1691479817,1691479817,1691479822,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','HARDWARE_BENCH_IMAGES','HardwareBenchmarks',0,1,'MARENOSTRUM0',113329,'',0,9,0.0,0.0,'a014_20210811_HardwareBenchmarks_HARDWARE_BENCH_IMAGES.20230808093032.out','a014_20210811_HardwareBenchmarks_HARDWARE_BENCH_IMAGES.20230808093032.err',5,'a014_20210811_HardwareBenchmarks_ADD_SECTION','');
INSERT INTO job_data VALUES(37,3,'a014_20210811_CompilationEfficiency_SCALABILITY_48','2023-08-08-09:30:17','2023-08-08-09:30:38',1691479817,1691479817,1691479822,'COMPLETED',2,48,'02:00','debug',0,'2021-08-11 00:00:00','SCALABILITY_48','CompilationEfficiency',0,1,'LOCAL',20949,'',0,9,0.0,0.0,'a014_20210811_CompilationEfficiency_SCALABILITY_48.20230808093038.out','a014_20210811_CompilationEfficiency_SCALABILITY_48.20230808093038.err',5,'a014_20210811_CompilationEfficiency_REPORT_SETUP','');
INSERT INTO job_data VALUES(38,3,'a014_20210811_CompilationEfficiency_FUNCTIONS_DIR','2023-08-08-09:30:17','2023-08-08-09:30:38',1691479817,1691479817,1691479822,'COMPLETED',2,192,'02:00','debug',0,'2021-08-11 00:00:00','FUNCTIONS_DIR','CompilationEfficiency',0,1,'LOCAL',20973,'',0,9,0.0,0.0,'a014_20210811_CompilationEfficiency_FUNCTIONS_DIR.20230808093038.out','a014_20210811_CompilationEfficiency_FUNCTIONS_DIR.20230808093038.err',5,'a014_20210811_CompilationEfficiency_TRACE_192,a014_20210811_CompilationEfficiency_TRACE_48,a014_20210811_CompilationEfficiency_TRACE_96,a014_20210811_CompilationEfficiency_TRACE_190','');
INSERT INTO job_data VALUES(39,3,'a014_20210811_WeakScaling_FUNCTIONS_DIR','2023-08-08-09:30:17','2023-08-08-09:30:38',1691479817,1691479817,1691479822,'COMPLETED',2,192,'02:00','debug',0,'2021-08-11 00:00:00','FUNCTIONS_DIR','WeakScaling',0,1,'LOCAL',20996,'',0,9,0.0,0.0,'a014_20210811_WeakScaling_FUNCTIONS_DIR.20230808093038.out','a014_20210811_WeakScaling_FUNCTIONS_DIR.20230808093038.err',5,'a014_20210811_WeakScaling_TRACE_384,a014_20210811_WeakScaling_TRACE_756','');
INSERT INTO job_data VALUES(40,3,'a014_20210811_HardwareBenchmarks_ADD_SECTION','2023-08-08-09:30:43','2023-08-08-09:31:02',1691479843,1691479843,1691479848,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','ADD_SECTION','HardwareBenchmarks',0,1,'MARENOSTRUM0',114356,'',0,9,0.0,0.0,'a014_20210811_HardwareBenchmarks_ADD_SECTION.20230808093102.out','a014_20210811_HardwareBenchmarks_ADD_SECTION.20230808093102.err',5,'a014_REPORT','');
INSERT INTO job_data VALUES(41,3,'a014_20210811_WeakScaling_TRACE_756','2023-08-08-09:30:45','2023-08-08-09:31:09',1691479844,1691479844,1691479849,'COMPLETED',2,756,'02:00','debug',0,'2021-08-11 00:00:00','TRACE_756','WeakScaling',0,1,'LOCAL',21082,'',0,9,0.0,0.0,'a014_20210811_WeakScaling_TRACE_756.20230808093109.out','a014_20210811_WeakScaling_TRACE_756.20230808093109.err',5,'a014_20210811_WeakScaling_REPORT_SETUP','');
INSERT INTO job_data VALUES(42,3,'a014_20210811_WeakScaling_TRACE_384','2023-08-08-09:30:46','2023-08-08-09:31:09',1691479846,1691479846,1691479851,'COMPLETED',2,384,'02:00','debug',0,'2021-08-11 00:00:00','TRACE_384','WeakScaling',0,1,'LOCAL',21106,'',0,9,0.0,0.0,'a014_20210811_WeakScaling_TRACE_384.20230808093109.out','a014_20210811_WeakScaling_TRACE_384.20230808093109.err',5,'a014_20210811_WeakScaling_REPORT_SETUP','');
INSERT INTO job_data VALUES(43,3,'a014_20210811_CompilationEfficiency_TRACE_192','2023-08-08-09:30:48','2023-08-08-09:31:09',1691479847,1691479847,1691479852,'COMPLETED',2,192,'02:00','debug',0,'2021-08-11 00:00:00','TRACE_192','CompilationEfficiency',0,1,'LOCAL',21129,'',0,9,0.0,0.0,'a014_20210811_CompilationEfficiency_TRACE_192.20230808093108.out','a014_20210811_CompilationEfficiency_TRACE_192.20230808093108.err',5,'a014_20210811_CompilationEfficiency_REPORT_SETUP','');
INSERT INTO job_data VALUES(44,3,'a014_20210811_WeakScaling_REPORT_SETUP','2023-08-08-09:31:13','2023-08-08-09:31:32',1691479873,1691479873,1691479878,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REPORT_SETUP','WeakScaling',0,1,'MARENOSTRUM0',115779,'',0,9,0.0,0.0,'a014_20210811_WeakScaling_REPORT_SETUP.20230808093132.out','a014_20210811_WeakScaling_REPORT_SETUP.20230808093132.err',5,'a014_20210811_WeakScaling_TRACE_CUT','');
INSERT INTO job_data VALUES(45,3,'a014_20210811_CompilationEfficiency_TRACE_190','2023-08-08-09:31:14','2023-08-08-09:31:38',1691479874,1691479874,1691479879,'COMPLETED',2,190,'02:00','debug',0,'2021-08-11 00:00:00','TRACE_190','CompilationEfficiency',0,1,'LOCAL',21213,'',0,9,0.0,0.0,'a014_20210811_CompilationEfficiency_TRACE_190.20230808093138.out','a014_20210811_CompilationEfficiency_TRACE_190.20230808093138.err',5,'a014_20210811_CompilationEfficiency_REPORT_SETUP','');
INSERT INTO job_data VALUES(46,3,'a014_20210811_CompilationEfficiency_TRACE_96','2023-08-08-09:31:16','2023-08-08-09:31:38',1691479875,1691479875,1691479880,'COMPLETED',2,96,'02:00','debug',0,'2021-08-11 00:00:00','TRACE_96','CompilationEfficiency',0,1,'LOCAL',21238,'',0,9,0.0,0.0,'a014_20210811_CompilationEfficiency_TRACE_96.20230808093138.out','a014_20210811_CompilationEfficiency_TRACE_96.20230808093138.err',5,'a014_20210811_CompilationEfficiency_REPORT_SETUP','');
INSERT INTO job_data VALUES(47,3,'a014_20210811_CompilationEfficiency_TRACE_48','2023-08-08-09:31:17','2023-08-08-09:31:38',1691479877,1691479877,1691479882,'COMPLETED',2,48,'02:00','debug',0,'2021-08-11 00:00:00','TRACE_48','CompilationEfficiency',0,1,'LOCAL',21261,'',0,9,0.0,0.0,'a014_20210811_CompilationEfficiency_TRACE_48.20230808093138.out','a014_20210811_CompilationEfficiency_TRACE_48.20230808093138.err',5,'a014_20210811_CompilationEfficiency_REPORT_SETUP','');
INSERT INTO job_data VALUES(48,3,'a014_20210811_CompilationEfficiency_REPORT_SETUP','2023-08-08-09:31:43','2023-08-08-09:32:01',1691479903,1691479903,1691479908,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REPORT_SETUP','CompilationEfficiency',0,1,'MARENOSTRUM0',116697,'',0,9,0.0,0.0,'a014_20210811_CompilationEfficiency_REPORT_SETUP.20230808093201.out','a014_20210811_CompilationEfficiency_REPORT_SETUP.20230808093201.err',5,'a014_20210811_CompilationEfficiency_TRACE_CUT','');
INSERT INTO job_data VALUES(49,3,'a014_20210811_WeakScaling_TRACE_CUT','2023-08-08-09:31:44','2023-08-08-09:32:05',1691479904,1691479904,1691479909,'COMPLETED',2,1,'02:00','debug',0,'2021-08-11 00:00:00','TRACE_CUT','WeakScaling',0,1,'LOCAL',21350,'',0,9,0.0,0.0,'a014_20210811_WeakScaling_TRACE_CUT.20230808093205.out','a014_20210811_WeakScaling_TRACE_CUT.20230808093205.err',5,'a014_20210811_WeakScaling_DIMEMAS,a014_20210811_WeakScaling_PARAMEDIR','');
INSERT INTO job_data VALUES(50,3,'a014_20210811_StrongScaling_PREPARE_TESTS','2023-08-08-09:31:46','2023-08-08-09:32:05',1691479905,1691479905,1691479910,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','PREPARE_TESTS','StrongScaling',0,1,'LOCAL',21374,'',0,9,0.0,0.0,'a014_20210811_StrongScaling_PREPARE_TESTS.20230808093205.out','a014_20210811_StrongScaling_PREPARE_TESTS.20230808093205.err',5,'a014_20210811_StrongScaling_FUNCTIONS_DIR,a014_20210811_StrongScaling_SCALABILITY_190','');
INSERT INTO job_data VALUES(51,3,'a014_20210811_StrongScaling_SCALABILITY_190','2023-08-08-09:32:05','2023-08-08-09:32:22',1691479925,1691479925,1691479930,'COMPLETED',2,190,'02:00','debug',0,'2021-08-11 00:00:00','SCALABILITY_190','StrongScaling',0,1,'LOCAL',21440,'',0,9,0.0,0.0,'a014_20210811_StrongScaling_SCALABILITY_190.20230808093222.out','a014_20210811_StrongScaling_SCALABILITY_190.20230808093222.err',5,'a014_20210811_StrongScaling_REPORT_SETUP','');
INSERT INTO job_data VALUES(52,3,'a014_20210811_WeakScaling_PARAMEDIR','2023-08-08-09:32:06','2023-08-08-09:32:22',1691479926,1691479926,1691479931,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','PARAMEDIR','WeakScaling',0,1,'LOCAL',21463,'',0,9,0.0,0.0,'a014_20210811_WeakScaling_PARAMEDIR.20230808093222.out','a014_20210811_WeakScaling_PARAMEDIR.20230808093222.err',5,'a014_20210811_WeakScaling_CONFIGURATION_JSON','');
INSERT INTO job_data VALUES(53,3,'a014_20210811_WeakScaling_DIMEMAS','2023-08-08-09:32:06','2023-08-08-09:32:22',1691479926,1691479926,1691479931,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','DIMEMAS','WeakScaling',0,1,'LOCAL',21486,'',0,9,0.0,0.0,'a014_20210811_WeakScaling_DIMEMAS.20230808093222.out','a014_20210811_WeakScaling_DIMEMAS.20230808093222.err',5,'a014_20210811_WeakScaling_CONFIGURATION_JSON','');
INSERT INTO job_data VALUES(54,3,'a014_20210811_WeakScaling_CONFIGURATION_JSON','2023-08-08-09:32:22','2023-08-08-09:32:39',1691479942,1691479942,1691479947,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','CONFIGURATION_JSON','WeakScaling',0,1,'LOCAL',21556,'',0,9,0.0,0.0,'a014_20210811_WeakScaling_CONFIGURATION_JSON.20230808093239.out','a014_20210811_WeakScaling_CONFIGURATION_JSON.20230808093239.err',5,'a014_20210811_WeakScaling_PARAVER','');
INSERT INTO job_data VALUES(55,3,'a014_20210811_CompilationEfficiency_TRACE_CUT','2023-08-08-09:32:23','2023-08-08-09:32:39',1691479943,1691479943,1691479948,'COMPLETED',2,1,'02:00','debug',0,'2021-08-11 00:00:00','TRACE_CUT','CompilationEfficiency',0,1,'LOCAL',21579,'',0,9,0.0,0.0,'a014_20210811_CompilationEfficiency_TRACE_CUT.20230808093239.out','a014_20210811_CompilationEfficiency_TRACE_CUT.20230808093239.err',5,'a014_20210811_CompilationEfficiency_PARAMEDIR,a014_20210811_CompilationEfficiency_DIMEMAS','');
INSERT INTO job_data VALUES(56,3,'a014_20210811_StrongScaling_FUNCTIONS_DIR','2023-08-08-09:32:23','2023-08-08-09:32:39',1691479943,1691479943,1691479948,'COMPLETED',2,192,'02:00','debug',0,'2021-08-11 00:00:00','FUNCTIONS_DIR','StrongScaling',0,1,'LOCAL',21602,'',0,9,0.0,0.0,'a014_20210811_StrongScaling_FUNCTIONS_DIR.20230808093239.out','a014_20210811_StrongScaling_FUNCTIONS_DIR.20230808093239.err',5,'a014_20210811_StrongScaling_TRACE_190','');
INSERT INTO job_data VALUES(57,3,'a014_20210811_StrongScaling_TRACE_190','2023-08-08-09:32:39','2023-08-08-09:32:56',1691479959,1691479959,1691479964,'COMPLETED',2,190,'02:00','debug',0,'2021-08-11 00:00:00','TRACE_190','StrongScaling',0,1,'LOCAL',21672,'',0,9,0.0,0.0,'a014_20210811_StrongScaling_TRACE_190.20230808093256.out','a014_20210811_StrongScaling_TRACE_190.20230808093256.err',5,'a014_20210811_StrongScaling_REPORT_SETUP','');
INSERT INTO job_data VALUES(58,3,'a014_20210811_WeakScaling_PARAVER','2023-08-08-09:32:39','2023-08-08-09:32:56',1691479959,1691479959,1691479964,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','PARAVER','WeakScaling',0,1,'LOCAL',21695,'',0,9,0.0,0.0,'a014_20210811_WeakScaling_PARAVER.20230808093256.out','a014_20210811_WeakScaling_PARAVER.20230808093256.err',5,'a014_20210811_WeakScaling_ADD_SECTION','');
INSERT INTO job_data VALUES(59,3,'a014_20210811_CompilationEfficiency_PARAMEDIR','2023-08-08-09:32:40','2023-08-08-09:32:56',1691479960,1691479960,1691479965,'COMPLETED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','PARAMEDIR','CompilationEfficiency',0,1,'LOCAL',21718,'',0,9,0.0,0.0,'a014_20210811_CompilationEfficiency_PARAMEDIR.20230808093256.out','a014_20210811_CompilationEfficiency_PARAMEDIR.20230808093256.err',5,'a014_20210811_CompilationEfficiency_CONFIGURATION_JSON','');
INSERT INTO job_data VALUES(60,3,'a014_20210811_WeakScaling_ADD_SECTION','2023-08-08-09:33:03','2023-08-08-09:33:03',1691479982,0,0,'SUBMITTED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','ADD_SECTION','WeakScaling',0,1,'MARENOSTRUM0',117751,'',0,9,0.0,0.0,'','',0,'a014_REPORT','');
INSERT INTO job_data VALUES(61,3,'a014_20210811_StrongScaling_REPORT_SETUP','2023-08-08-09:33:08','2023-08-08-09:33:08',1691479988,0,0,'SUBMITTED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','REPORT_SETUP','StrongScaling',0,1,'MARENOSTRUM0',118422,'',0,9,0.0,0.0,'','',0,'a014_20210811_StrongScaling_TRACE_CUT','');
INSERT INTO job_data VALUES(62,3,'a014_20210811_CompilationEfficiency_DIMEMAS','2023-08-08-09:33:08','2023-08-08-09:33:08',1691479988,0,0,'SUBMITTED',2,1,'00:30','debug',0,'2021-08-11 00:00:00','DIMEMAS','CompilationEfficiency',0,1,'LOCAL',21805,'',0,9,0.0,0.0,'','',0,'a014_20210811_CompilationEfficiency_CONFIGURATION_JSON','');
DELETE FROM sqlite_sequence;
INSERT INTO sqlite_sequence VALUES('experiment_run',9);
INSERT INTO sqlite_sequence VALUES('job_data',62);
CREATE INDEX ID_JOB_NAME ON job_data(job_name);
COMMIT;
